triton-ascend
A language and compiler for custom Deep Learning operations on Ascend hardwares
Decision gist · record as of 2026-08-14
Yes, if you develop on Ascend hardware and want to write custom kernels with reduced complexity compared to native operator development. No, if you target GPU or CPU platforms—this is Ascend-specific. The package is actively maintained and has no known vulnerabilities, but license metadata is unclear and Python version support is unspecified, so verify compatibility with your environment before committing.AI-flagged interpretation of the facts on this page — verify before relying
Before you install
- Requires Ascend hardware (Atlas 800T/I A2 product line), Ubuntu Linux host, and x86_64 or aarch64 CPU architecture.
- Medium install friction due to platform-specific wheels (x86_64 and aarch64 Linux only, Python 3.10 and 3.11 supported).
- No runtime dependencies, but requires Ascend hardware and Ubuntu Linux host to be useful.
License · maintenance · safety
(unclear) — License treatment is unclear—the description references MIT licensing, but the fact sheet does not confirm SPDX or raw license metadata, so actual licensing terms cannot be verified from this data.
last release 2026-01-21 (205 days)
0 known vulnerabilities (OSV.dev, 2026-08-14) · 180,192 downloads/mo, #10,152 on PyPI
Alternatives
Verify before relying
pip install triton-ascend==3.2.0
import triton
import triton.language as tl
@triton.jit
def kernel(x_ptr, y_ptr, n_elements, BLOCK_SIZE: tl.constexpr):
pid = tl.program_id(axis=0)
block_start = pid * BLOCK_SIZE
offsets = block_start + tl.arange(0, BLOCK_SIZE)
x = tl.load(x_ptr + offsets)
y = x + 1
tl.store(y_ptr + offsets, y)- Exact Python version support—wheels exist for cp39, cp310, cp311 but requires_python is unspecified
- Whether the Triton Python API coverage claim is current as of version 3.2.0
- Performance characteristics and optimization guarantees compared to native Ascend operator development
- Pre-integration status with vLLM, sglang, and Flaggems mentioned in roadmap
What it is and what it does
Triton Ascend is a compiler framework that translates Triton code—a Python-like language for writing custom deep learning kernels—into optimized machine code for Ascend hardware. Developers write kernels by specifying tile/block decomposition and block-level computation logic; the compiler automatically handles memory layout, data movement, and pipeline parallelism, reducing operator development complexity.
The framework targets Ascend accelerators (Atlas 800T/I A2 products) on Ubuntu Linux with x86_64 or ARM host CPUs. It supports Triton Python API, continuous memory access patterns, and atomic operations. The project is actively maintained, with recent updates adding Scan/Sort operators, non-contiguous memory access, and compatibility with open-source repositories.
Use it for
- Develop fused kernels (softmax, layer norm, attention) for Ascend-based inference or training without hand-coding low-level hardware operations.
- Port existing Triton kernels from GPU platforms to Ascend by adapting memory access patterns and API constraints.
- Implement custom matrix multiplication and tensor operations optimized for Ascend's memory hierarchy using Triton's autotune capability.
- Build high-performance operators for large language model inference on Ascend hardware with reduced development effort.
- Profile and optimize Triton kernels on Ascend using MindStudio tools for performance tuning and memory safety.
Worth the install?
AI-flagged interpretation of the facts on this page. Verify before relying on it.
Yes, if you develop on Ascend hardware and want to write custom kernels with reduced complexity compared to native operator development.
No, if you target GPU or CPU platforms—this is Ascend-specific. The package is actively maintained and has no known vulnerabilities, but license metadata is unclear and Python version support is unspecified, so verify compatibility with your environment before committing.
Install
triton-ascend on PyPI
Before you install
Medium install friction due to platform-specific wheels (x86_64 and aarch64 Linux only, Python 3.10 and 3.11 supported). No runtime dependencies, but requires Ascend hardware and Ubuntu Linux host to be useful.
Requires Ascend hardware (Atlas 800T/I A2 product line), Ubuntu Linux host, and x86_64 or aarch64 CPU architecture.
License in practice
License treatment is unclear—the description references MIT licensing, but the fact sheet does not confirm SPDX or raw license metadata, so actual licensing terms cannot be verified from this data.
Quickstart
pip install triton-ascend==3.2.0
import triton
import triton.language as tl
@triton.jit
def kernel(x_ptr, y_ptr, n_elements, BLOCK_SIZE: tl.constexpr):
pid = tl.program_id(axis=0)
block_start = pid * BLOCK_SIZE
offsets = block_start + tl.arange(0, BLOCK_SIZE)
x = tl.load(x_ptr + offsets)
y = x + 1
tl.store(y_ptr + offsets, y)
Verify before relying
- Exact Python version support—wheels exist for cp39, cp310, cp311 but requires_python is unspecified
- Whether the Triton Python API coverage claim is current as of version 3.2.0
- Performance characteristics and optimization guarantees compared to native Ascend operator development
- Pre-integration status with vLLM, sglang, and Flaggems mentioned in roadmap
Package facts
| License | Not declared unclear |
| Python support | Not specified |
| Install friction | Medium. Platform-specific wheel |
| Runtime dependencies | None |
| Maintenance | Aging 205 days since the last release |
| First released | |
| Downloads | 180,192 / month, #10,152 on PyPI 30-day window, as of 2026-08-14 |
| Known vulnerabilities | None known OSV.dev, checked 2026-08-14 |
Evidence: triton_ascend-3.2.0-cp310-cp310-manylinux_2_27_aarch64.manylinux_2_28_aarch64.whl; triton_ascend-3.2.0-cp310-cp310-manylinux_2_27_x86_64.manylinux_2_28_x86_64.whl; triton_ascend-3.2.0-cp311-cp311-manylinux_2_27_aarch64.manylinux_2_28_aarch64.whl; triton_ascend-3.2.0-cp311-cp311-manylinux_2_27_x86_64.manylinux_2_28_x86_64.whl; triton_ascend-3.2.0-cp39-cp39-manylinux_2_27_aarch64.manylinux_2_28_aarch64.whl; triton_ascend-3.2.0-cp39-cp39-manylinux_2_27_x86_64.manylinux_2_28_x86_64.whl
Tags
Let your AI agent find packages like this
Example. Real query, live index.
You found this page by searching. An agent finds it by wishing: SkillFed indexes 14,416 PyPI packages by what they can do, searchable in plain language.
wish › “triton compiler ascend hardware”
- triton-ascendTriton Ascend is a compiler framework that enables Triton code to run…
- torch-npuEnables PyTorch to run computations on Huawei Ascend NPU hardware,…
- tokenspeed-tritonTriton is a language and compiler for writing custom deep-learning…
Give your agent the search over MCP, or paste the wish link into any chat.
More Artificial Intelligence packages
LiteLLM provides a unified Python interface to call 100+ LLM providers (OpenAI, Anthropic, Gemini, Bedrock, Azure, and others) using OpenAI-compatible API format, available as both a Python SDK and a self-hosted AI Gateway proxy server.
Install it if you need to work with multiple LLM providers or want to centralize LLM routing in your organization.
Client library and CLI tool for downloading, uploading, and managing models, datasets, and repositories on the Hugging Face Hub platform.
Install it if you work with Hugging Face Hub models or datasets.
LangChain provides a framework for building agents and LLM-powered applications by composing language models, tools, and memory through a unified API that abstracts over multiple model providers.
hf-xet provides chunk-based deduplication and efficient file transfer for the Hugging Face Hub, enabling faster uploads and downloads of large files with local disk caching.
Tokenizers converts raw text into token sequences for NLP models, with support for training custom vocabularies and using pre-built tokenizers (BPE, WordPiece) optimized for speed via Rust.
Transformers provides a unified framework for loading, fine-tuning, and running state-of-the-art pretrained models across text, vision, audio, video, and multimodal tasks using PyTorch, JAX, or TensorFlow.
Install it if you need to run or train any transformer-based model for NLP, vision, audio, or multimodal tasks.
See also helion · tokenspeed-triton · triton-windows · triton · liger-kernel · tokamax · flash-attn · tilelang · quadrants · torch-npu